@@ -20,6 +20,7 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <khtml_part.h>
+#include <khtmlview.h>
 #include <kglobalsettings.h>
 
 #include <qvbox.h>
@@ -167,6 +168,13 @@ void reportView::render(){
     m_reportView->begin();
     m_reportView->write( contents );
     m_reportView->end();
+	
+    QScrollView *view = m_reportView->view();
+    kdDebug() << "Size " << view->size().height() << "," << view->size().width() << endl;
+    kdDebug() << "Size " << view->visibleHeight() << "," << view->visibleWidth() << endl;
+
+    m_reportView->view()->resize(view->size().width(), view->size().height());
+
 }
 
 #include "reportview.moc"
